package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0,````````````"``\````!``$;V````#0``-W<```"$``T`"``
M!P`H`!P`&P````8````T``$`-``!`#0```#@````X`````4````$`````P``
M`10``0$4``$!%`````T````-````!`````$````!```````!`````0````#6
MD```UI`````%```0``````$``-:0``'FD``!YI````/\```42`````<``!``
M`````@``UJ0``>:D``'FI````/````#P````!@````0````$```!)``!`20`
M`0$D````(````"`````$````!&1TY5```-9(``'62``!UD@````4````%```
M``0````$+VQI8B]L9"YS;RXQ``````````0````0`````4=.50``````````
M`@````8````)````80```'0````2``````````````!?`````````&L```!J
M``````````````!3````6@```$\```!!````1P```#0`````````20```'``
M```#````.0```&0````;````10```$,``````````````%$```!7````.P``
M``````!8````&````&8```!-````$0````````!O````<0```$0```!S````
M`````&,`````````80````````!B````5``````````C````"@```%(`````
M````,0``````````````0@```!`````X````:0``````````````2P``````
M``!;```````````````W`````````%T````N````$P```$````!N````!P``
M````````````"````"P```!5````,````'(````H````3``````````5````
M```````````Z````1@```%P`````````90```!H```!>````:````&T`````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````&````#0``
M````````````````````````````%P`````````````````````````,````
M``````X````````````````````9````````````````````%``````````$
M````)@```"(``````````@```"\````?````````````````````````````
M```S```````````````R````-@````D``````````0````\`````````!0``
M`!T`````````````````````````````````````````(0```#X````M````
M/P```!8````E```````````````<````(````"<`````````4``````````U
M`````````"L```!*```````````````I````5@```%D`````````````````
M````````/0```!X```!@````*@```$@`````````9P```#P````D````````
M``````!.````;`````L````````````````````````%#P`!YY0`````(```
M%0``!-H````````!C!(```````14``$EQ````"@2```+```$90`!*.0```"$
M$@``"P```"<`````````"!(````````^`````````"@2```````$$0`!ZI``
M```$(0``&```!'(``7*0````!!(```L```/&`````````!02```````%$P`!
M&]@```!0$@``"P```$@````````%6!(```````-,`````````,P2````````
M4P````````!,$@```````Q4`````````M!(```````.<`````````102````
M````9@`!=30````$(@``"P```'4``````````"````````")``````````@2
M```````$&0````````!@$@```````A@````````#@!(```````"=````````
M``@2````````KP`````````($@``````!'P``74X`````!(```P```2"``%E
MW```!O@2```+```#)0````````&\$@``````!)@``2U@````G!(```L```2F
M``$DC````3@2```+```$$``!ZI`````$(0``&````PT`````````R!(`````
M``.C`````````$P2````````O`````````18$@```````X<`````````U!(`
M``````#%`````````ZP2````````TP````````!P$@```````!$``>IL````
M`!$`__$```2\``$I:````@`2```+```$R``!55````!<$@``"P```.,`````
M```!F!(```````3C``%A;````*@2```+```#YP````````&<$@```````T0`
M````````M!(```````3O``'GK`````01```5````\0````````'8$@``````
M!6D``7C0``!:N!$```T```3^``%U<`````01```-````_``````````,$@``
M`````\T`````````3!(```````0/``'JD`````01```8```!$`````````-D
M$@``````!",`````````8!(```````-R`````````0`2```````%#0`!YY0`
M````$```%0```1X`````````"!(```````$P`````````)@2```````#N```
M``````!`$@```````VH````````#P!(```````$^````````"A@2```````%
M&@`!YY0`````$0``%0```X``````````;!(```````%.`````````$P2````
M```#]@`````````L$@```````5\````````!C!(```````%P````````!E`2
M```````#W0````````%0$@```````S<````````!'!(```````4C``$=)```
M`'02```+```!?P````````&4$@```````SP`````````/!(```````-D````
M`````$P2```````%*P`!<I0```"H$@``"P```WD`````````%!(```````&.
M`````````S`2```````!G````````!($$@``````!$,``>J,`````!``__$`
M``-5`````````-@2```````!J@````````$4$@```````Y4`````````R!(`
M``````&V``````````@2```````!QP`````````($@```````_T````````!
MH!(```````-=`````````$P2```````#U@````````2\$@```````OD`````
M````2!(```````4[``%E3````)`2```+```!V0````````!<$@```````>X`
M````````"!(```````1/``'ZV``````0`/_Q```%5P`!7]0```&8$@``"P``
M`O0`````````Q!(```````(,`````````(`2```````"'P````````"X$@``
M````!60``>>H````!!$``!4```!#`````````:02```````"[0````````$X
M$@```````BP`````````"!(```````5S``'ZU`````01```8```"/@`!ZI@`
M```3$0``&```!8$``5<T```(H!(```L```/O`````````$P2```````$/``!
MZHP`````$`#_\0```DT````````#`!(```````6.``%5K````8@2```+```%
MH``!)>P```+X$@``"P```[`````````!$!(```````)8`````````'`2````
M```"9P`````````,$@```````GD`````````"!(```````*.``````````@2
M```````#J0````````#H$@```````XX`````````T!(```````6M``$K:```
M`?@2```+```$"@`!;7@```3P$@``"P``!24``1<0`````!(```H```*?````
M`````(P2```````"M@````````@4$@````!L:6)P97)L+G-O+C4N,3``7T=,
M3T)!3%]/1D93151?5$%"3$5?`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R
M;%]F<F5E`'!E<FQ?<&%R<V4`4&5R;%]A=&9O<FM?=6YL;V-K`%]?9VUO;E]S
M=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%])979A;%]R;V]T7W!T
M<@!097)L7TEI;E]E=F%L7W!T<@!097)L7TEO<%]P='(`<&5R;%]R=6X`4&5R
M;%]A=E]S:&EF=`!097)L7V=V7V9E=&-H<'8`4&5R;%]S=E]S971P=@!P97)L
M7V%L;&]C`%!E<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%]D;W5N=VEN9`!097)L
M7TET86EN=&5D7W!T<@!097)L7W-Y<U]T97)M`&)O;W1?1'EN84QO861E<@!0
M97)L7V%T9F]R:U]L;V-K`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]C;VYS=')U
M8W0`4&5R;%]S=E]S971P=FX`4&5R;%]A=E]F971C:`!P97)L7V1E<W1R=6-T
M`%!E<FQ?;6=?<V5T`%!E<FQ?27!A<G-E<E]P='(`4&5R;%])<W1A=&)U9E]P
M='(`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&5R;%]D97-T<G5C=%]L
M979E;%]P='(`4&5R;%]S869E<WES;6%L;&]C`%!E<FQ?;F5W4U9P=@!097)L
M7TET;W!?96YV7W!T<@!03%]M96UO<GE?=W)A<`!097)L7VYE=UA3`%!E<FQ?
M<WES7VEN:70S`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?265X:71?9FQA9W-?
M<'1R`%!E<FQ?26-O;7!C=E]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!0
M97)L7W-V7S)P=E]F;&%G<P!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR
M96%D+G-O+C``;W!E;C8T`')E860`<'1H<F5A9%]G971S<&5C:69I8P!L<V5E
M:S8T`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-P
M<FEN=&8`<W1R;F-M<`!C;&]S961I<@!S=')N8W!Y`'5N;&EN:P!M:V1I<@!R
M96%L;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M
M<V5T`'-T<G-T<@!R;61I<@!M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C
M`&=E='5I9`!R96%D;&EN:P!E>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C
M97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A
M=#8T`%]?;'AS=&%T-C0`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A
M<G0`7V5N9`!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?
M8W-U7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'-I>F5?;&]A9%]M95\R`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=``D9VQO8F%L)`!X<U]I;FET`%]?
M;&EB8U]C<W5?:6YI=`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<&%R
M7W)M=&UP9&ER`&YA;65?;&]A9%]M95\R`%]?=&AR96%D7W-E;&8`<&%R7VUK
M=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXR`$=,24)#7S(N,P!'3$E"0U\R+C,N,@`````!``(`
M`0`!```````"``$``@`!`````@````,``@`!```````"``(```````$``0`$
M``$``0`"``,``@````(```````$``0`!`````0`"``(``0````$``0````(`
M`@````(``@`!```````%``(````!``(````"```````"``(``0````(``@`!
M``(```````$``@````(```````(``@`"``,``0```````0`!``,```````$`
M`@`#`````0````$``@`!`````0`!``(````````````"``(``0`!``$`````
M`````0`!```"W0```!`````@#6EI$@````,```6Z```````!``,```,;````
M$``````-:6D3````!0``!<0````0"6D9<@````0```7.````$`UI:1(````"
M```%N@```````>I\```C`0```````>J0```P@````````>J8``!A@```````
M`>?````"@0```````>?(```%@0```````>?0```&@0```````>?8```(@0``
M`````>?@```)@0```````>?H```+@0```````>?P```,@0```````>?X```-
M@0```````>@````.@0```````>@(```/@0```````>@0```0@0```````>@8
M```1@0```````>@@```2@0```````>@H```3@0```````>@P```4@0``````
M`>@X```5@0```````>A````6@0```````>A(```8@0```````>A0```9@0``
M`````>A8```=@0```````>A@```>@0```````>AH```?@0```````>AP```@
M@0```````>AX```A@0```````>B````B@0```````>B(```F@0```````>B0
M```H@0```````>B8```I@0```````>B@```K@0```````>BH```N@0``````
M`>BP```O@0```````>BX```Q@0```````>C````R@0```````>C(```S@0``
M`````>C0```U@0```````>C8```V@0```````>C@```W@0```````>CH```X
M@0```````>CP```Y@0```````>CX```[@0```````>D````\@0```````>D(
M```]@0```````>D0```^@0```````>D8```_@0```````>D@``!`@0``````
M`>DH``!!@0```````>DP``!#@0```````>DX``!$@0```````>E```!%@0``
M`````>E(``!&@0```````>E0``!'@0```````>E8``!(@0```````>E@``!)
M@0```````>EH``!+@0```````>EP``!,@0```````>EX``!-@0```````>F`
M``!.@0```````>F(``!/@0```````>F0``!0@0```````>F8``!1@0``````
M`>F@``!2@0```````>FH``!3@0```````>FP``!5@0```````>FX``!6@0``
M`````>G```!9@0```````>G(``!:@0```````>G0``!;@0```````>G8``!=
M@0```````>G@``!>@0```````>GH``!?@0```````>GP``!C@0```````>GX
M``!E@0```````>H```!H@0```````>H(``!I@0```````>H0``!J@0``````
M`>H8``!K@0```````>H@``!L@0```````>HH``!M@0```````>HP``!N@0``
M`````>HX``!P@0```````>I```!R@0```````>I(``!S@0`````K8```2#4`
M^.J@P`!(,P$`:\(_V6_$`(!KTS_!Z%\?O0@3`D0(!`)3Z$`+2`@``D#H0AKD
M"``"0$O"/UD(!`)3Z$#``$_$/X$K8```2#4#R.J@P`!(,P/0*V```$@U!-CJ
MH,``2#,$X"M@``!(-0-8ZJ#``$@S`V`K8```2#4$*.J@P`!(,P0P*V```$@U
M`&CJH,``2#,`<"M@``!(-0(8ZJ#``$@S`B`K8```2#4$>.J@P`!(,P2`*V``
M`$@U`@CJH,``2#,"$"M@``!(-01HZJ#``$@S!'`K8```2#4#^.J@P`!(,P0`
M*V```$@U`%CJH,``2#,`8"M@``!(-0)8ZJ#``$@S`F`K8```2#4$2.J@P`!(
M,P10*V```$@U!+CJH,``2#,$P"M@``!(-0"HZJ#``$@S`+`K8```2#4#J.J@
MP`!(,P.P*V```$@U`LCJH,``2#,"T"M@``!(-0'(ZJ#``$@S`=`K8```2#4!
MZ.J@P`!(,P'P*V```$@U`+CJH,``2#,`P"M@``!(-0-XZJ#``$@S`X`K8```
M2#4!>.J@P`!(,P&`*V```$@U!5CJH,``2#,%8"M@``!(-0+HZJ#``$@S`O`K
M8```2#4$B.J@P`!(,P20*V```$@U!3CJH,``2#,%0"M@``!(-0,8ZJ#``$@S
M`R`K8```2#4$R.J@P`!(,P30*V```$@U`=CJH,``2#,!X"M@``!(-0(HZJ#`
M`$@S`C`K8```2#4">.J@P`!(,P*`*V```$@U`RCJH,``2#,#,"M@``!(-0-(
MZJ#``$@S`U`K8```2#4$Z.J@P`!(,P3P*V```$@U`'CJH,``2#,`@"M@``!(
M-0*8ZJ#``$@S`J`K8```2#4`Z.J@P`!(,P#P*V```$@U!!CJH,``2#,$("M@
M``!(-0/HZJ#``$@S`_`K8```2#4!^.J@P`!(,P(`*V```$@U`JCJH,``2#,"
ML"M@``!(-0.8ZJ#``$@S`Z`K8```2#4#B.J@P`!(,P.0*V```$@U!*CJH,``
M2#,$L"M@``!(-05HZJ#``$@S!7`K8```2#4$^.J@P`!(,P4`*V```$@U`3CJ
MH,``2#,!0"M@``!(-0,XZJ#``$@S`T`K8```2#4$6.J@P`!(,P1@*V```$@U
M!)CJH,``2#,$H"M@``!(-0$HZJ#``$@S`3`K8```2#4!N.J@P`!(,P'`*V``
M`$@U`DCJH,``2#,"4"M@``!(-0/8ZJ#``$@S`^`K8```2#4"..J@P`!(,P)`
M*V```$@U`9CJH,``2#,!H"M@``!(-0$8ZJ#``$@S`2`K8```2#4%*.J@P`!(
M,P4P*V```$@U!1CJH,``2#,%("M@``!(-04(ZJ#``$@S!1`K8```2#4"B.J@
MP`!(,P*0*V```$@U!#CJH,``2#,$0"M@``!(-0,(ZJ#``$@S`Q`K8```2#4!
MJ.J@P`!(,P&P*V```$@U`OCJH,``2#,#`"M@``!(-0%8ZJ#``$@S`6`K8```
M2#4`V.J@P`!(,P#@*V```$@U`8CJH,``2#,!D"M@``!(-0)HZJ#``$@S`G`K
M8```2#4$".J@P`!(,P00*V```$@U`4CJH,``2#,!4"M@``!(-0"8ZJ#``$@S
M`*`K8```2#4#N.J@P`!(,P/`#\`2F6O"/]DWW@"`#]X2F6O3/\%KUS^1(TL@
M`$M:"L`BZR``2O<*V"++(`!*U@K0:]8_F6O>/XDC;P``-WL/*.A?%W4(``)`
M!`````@``D```%=D:\(_V2M@``!`/`8P;\8`@`@!`D9KQ3^):\0_D8^`(+!K
MPS^9*V````@!`E-(/`8X*W___S0E#@@K?___-"$.$`BA!`'0(1^B-",__X.#
MH$`V9`8X-YP``@R<$H`,O""6Z^(-U`@?`D(,@!"<BX._S3><``(T'``"8-P&
M,$O"/UE+Q3^)2\0_D4O#/YGH0,``3\8_@6O"/]DWW@"`2\(_6>A`P``WWC^!
M:\(_V2M___\WW@"`2#P.&(>`(#`T.@X8(XL@`$N6"NB&P"`82\(_6>OB#/0(
M'P)"2\(_6>A`P``WWC^!:\(_V3?>`(!+PC]9Z$#``#?>/X%KPC_9"`,"00@>
M`D-OP0"`(XL@`#><"O`,?!*0-!H``.A?&9T(``)`#X`0G`@<`EKH7Q0]"``"
M0`@<`E,CBR``-YP+0`^`$)0($P):(XL@`#>9"P@(%`)8#'`0E^A?%N4(``)`
M2&(_V31^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!((!H>3^Q:'@_J31S`!@C
MBR``-YH+2`@3`EDT&!_^Z%\9O0@``D`,?!*0#'`0G(^`0$H,<!"<-Y,__S1\
M`!@*?`H<#X`0'-.<'_B/@"`2#'`0G#></_\,?!*0#'`0G(^`0+H,<!"3-'P`
M&`@<`EHT&0!>"!,"6.A?&LT(``)`AX`@>C0:``#H7Q?-"``"0`^`$)P('`):
MZ%\2;0@``D`,<!"4-',`&`@<`EI(>3^Q"!,"6`@4`E?H7Q>M"``"0.@``%HT
M&@``Z%\730@``D`/@!"<"!P"6NA?$>T(``)`"!P"6DAY/[%(>#^IZ%\3I0@`
M`D!(8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$!`&AZ/[EH>3^Q2',_
MN89@(!HK8```-#P%^`^`$)R/@"`*:&``,.@``?I(?#^Y:'P`(.@``!)(<P`@
M-G,``FAS`"!(<P`@#F`0'-.<'_B'@"`J2',`(`Y@$!S3DQ_X-!P`>HI\/YT(
M``)`2',`($A\/[D+DP03:',`*"M@```T/`7X#X`0G`Q\$ICH``#Z2'P`*`QP
M$)I(>3^Y"!P"6.A?$+T(``)`CX`@JDA\`"@,<!"3"Y,*'`^`$!S3DQ_X-!P`
M>HI\('(,>!"3*V```#0\!?@/@!"<"Y,$'-.<'Z(('`)32'P_L0^3$H!(?``H
M-YP``@QP$),+DPH<:'P`,.@``$H,>!"<-YP`"`Q\$I@,>!"3#F`0DPQS$I`,
M<!"<CX`^U0@``D!H8``P2'P`,$AB/]DT?@"`3\,_@>A`P`)KPC_9"`,"00@>
M`D-OP0"`:'H_N4AZ/[DT?``0"!P"6>A?'1T(``)`2&(_V31^`(!/PS^!Z$#`
M`FO"/]D(`P)!"!X"0V_!`0!H9`!`:'H_N6AY/[%(83^Q#"`0'-.3'_@T'`!Z
MBGP@$DAS/[$V<P`":',_L4AZ/['H7Q#-"``"0`Q\$I`T?``82'H_N0@<`EGH
M7QP]"``"0&A\`#!(=``PAH`@TDAZ`##H7Q!M"``"0`@<`E,,<!"<BGRC0DAA
M/[$,(!`<TYP?^$AS`#`.?!(`2'0`,`Z`$!S3G!_XDYP@`#0<``+3G!OX2&$`
M,#0A``)H80`P2',_L39S``)H<S^QCX`_;0@``D!H8``XZ``%NBM@```T/`7X
M#X`0G&A\`"!H8``HZ```*DAT`"`VE``(:'0`($A\`"@WG``":'P`*$AA`"`,
M(!"<CX`_M0@``D`K8```-#P&0`^`$)R'@""R*V```#0\!?@/@!"32'0`*#:<
M``37G`A""!,"6@@<`EGH7Q"="``"0`@<`E,K8```"`$"7#><!?@/DQ*`*V``
M``@!`EPWG`7X#X`0G(^`(0HT$S__:',`..@`!&(K8```-#,&0#0<``(.?!*`
M2'0`*#:<``37G`A""!P"6NA?$*4(``)`:'P`($A\`""/@"`2-`$__VAA`#CH
M``/B*V```#0\!?@/@!"32'P`*-><"$)(>@`@"!,"60@<`ECH7P]%"``"0"M@
M```(`0)<-YP%^$AS`"`/DQ*`*V```#0\!?@/@!"32'P`*#><``+7G`A""Y,*
M'`^`$H!(?``H#'P2F$AT/[EH=``PZ```$DA\`#`WG``":'P`,$AA`#`,(!`<
MTYP?^(>`("I(<P`P#F`0'-.3'_@T'`!ZBGP_G0@``D`K8```-#P%^`^`$),,
M>!"<UYP(0@N3"@1(<P`P2'P_N0N3!!P('`)3#'`0G`N3"APWG``$"!P"6NA?
M#JT(``)`#)P2@`R`$)R/@"`2-!0__VAT`#CH``'J*V```#0\!?@/@!"3#'@0
MG-><"$(+DPH<#X`0G&A\`##H```22'P`,#><``)H?``P2'P_N0^`$!S3G!_X
M2&$`,`P\$@!(<P`P#F`0'-.<'_B3G"``-!P``M.3&_A(?#^Y-YP``FA\/[DT
M'``""Y,"G-.<&_B/@"`J2'0`,`Z`$!S3DQ_X-!P`>HI\/RT(``)`-!P`>DAA
M`#`,/!(`2',`,#9S``)H<P`P2'0_L0Z`$!S3G!_X2&$`,`P\$@!(<P`P#F`0
M'-.<'_B3G"``-!P``M.<&_A(=``P-I0``FAT`#!(83^Q-"$``FAA/[&/@#]M
M"``"0&A@`#A(?``X2&(_V4AD`$`T?@"`3\,_@>A`P`)KPC_9"`,"00@>`D-O
MP0"`:'H_N>@``)(K8```-#P%^`^`$),,<!"<UYP(0@N3"A,,<Q*8#'@0DS9\
M``@/@!"<#'@0DPY\$H`,>!"3#F`0G(>`(!H,>!"<-YP`"`Q\$ICH'Q^?2'H_
MN31\`!`('`)9Z%\4;0@``D"/@#\U"``"0$AB/]DT?@"`3\,_@>A`P`)KPC_9
M"`,"00@>`D-OP3^`-]X!@`Q@$ICH7P>]"``"0`@<`E,T?``@"!P"6B.+(``W
MF0MX"!,"6".+(``WEPN0Z%\([0@``D`,?!*0#'`0G(>`8"(B8@``-G,`*0AS
M"A,.8!*`Z``!6C1\`"`T<R`B"!P"6@@3`EDT&"``Z%\+-0@``D`,?!*0#'`0
MG(>`8"(C@@``-YP`*0A\"AP/@!*`Z```X@QP$)PWG``""!P"6NA?"<T(``)`
M#'P2F`QX$)R/@"`B(F(``#9S`"D(<PH3#F`2@.@``'H,<!"3-'P@(@QX$)H(
M'`)9"!,"6.A?"K4(``)`#'`0DPQX$)P*?`H<#X`2``QX$),C@@``-YP`*0A\
M"AP/DQ*`(F(``#9S`"D(<PH3#F`0G$AB/]DT?@"`3\,_@>A`P`)KPC_9"`,"
M00@>`D-OP0"`Z%\=90@``D!(8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#
M;\$A`&AZ/[EH>3^Q(XL@`#>:"YCH7Q/%"``"0`Q\$I`K8```"`$"7#><`!`/
M@!"<2'H_N0@<`EGH7P:E"``"0(>`(#HCBR``-YH+L$AY/[GH7Q.]"``"0$A\
M/[EH?"`PZ``$XDAZ/[GH7P3E"``"0&A\`"`K8```"`$"7#><`!@/@!"<2'H_
ML0@<`EGH7P?="``"0&A\`"CH``0B2'P`*`^`$!S3G!_XCX`@$B.+(``WG`O0
M:'P`*`QP$)R'@"!J#'`0FDAY`"CH7P/E"``"0(^`($(K8```-#P`&`^`$)PT
M&@``"!P"6>A?!R4(``)`:'P`*.@``VI(>@`HZ%\#O0@``D`,?!*8Z```,@QX
M$)PWG#__#'P2F`QX$)-(?``H"GP*'`^`$@`,>!"<-Y,__TA\`"@*?`H<#X`0
M'-.3'_@K8```-#P`$`^`$)P/@!`<TYP?^()\/V4(``)`#'@0G#>3``)(?``@
M"Y,*$S0<'_Z*?$`Z(XL@`#>:"[!(>3^YZ%\170@``D!(?#^Y:'P@,.@``H(K
M8```-#P`$`^`$)0T<P`P2'P_N6O</YD($P):(XL@`#>9"]A(>``H"!0"5^A?
M`Q4(``)`-!H``.A?!)T(``)`#X`0G`@<`EKH7Q\Y"``"0`@<`EKH7P.%"``"
M0`@<`E,T?``P"!P"6@@3`EGH0A9X"``"0(^`(0(T&@``Z%\$%0@``D`/@!"<
M"!P"6NA?'K$(``)`"!P"6NA?`OT(``)`2Y,`(".'(``+DP(3(X0``(I\((HT
M?``P"!P"6C09``+H7Q^)"``"0(^`(%HT<P`P(XL@`#>:"[`($P)9Z%\/?0@`
M`D`T?``P"!P"6NA?'Y$(``)`:'P@,.@``(HK8```-#P`&`^`$)PT&@``"!P"
M6>A?`ZT(``)`:'P`*$A\`"B/@#O%"``"0".+(``WF@NP2'D_N>A?#LT(``)`
M2&$_N6AA(#!(?"`P2&(_V31^`(!/PS^!Z$#``@@#`D$('@)#;\$`@&AZ/[E(
M?#^Y#'P2F$A\/[D,?!*0Z```<@QP$)P/@!`<TY,?^"M@```T/``0#X`0G`^`
M$!S3G!_XBGP@$@QP$)PWG``"#'P2F`QP$)PWG``"#'P2D`QP$)P/@!`<TYP?
M^(^`/V4(``)`#'@0G#1^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!`(!H>C^Y
M2'P_N8>`(!I(?#^Y#X`0'-.<'_B/@"`J(XL@`#>:"]#H7QU)"``"0`Q\$ICH
M``-*2'H_N>A?'D$(``)`-Y,__TA\/[D*?`H<#'P2D.@``!(,<!"!-"$__PQA
M$I!(?#^Y#'`0DXI\@&H,<!"!#"`0'-.3'_@K8```-#P`$`^`$)P/@!`<TYP?
M^()\/X4(``)`Z```$@QP$),V<S__#',2D$A\/[D,<!"!B#R`2@QP$),.8!`<
MTY,?^"M@```T/``0#X`0G`^`$!S3G!_XBGP_A0@``D!(?#^Y#'`0@8@\(+(,
M<!"3#F`0'-.3'_@K8```-#P`$`^`$)P/@!`<TYP?^(I\("HCBR``-YH+T.A?
M&W$(``)`#'P2F.@``7(K8```-#P`$`^`$)P('`):Z%\;,0@``D`,?!*8Z``!
M,@QP$)PWG#__#'P2D$A\/[D,<!"!B#R`2@QP$),.8!`<TY,?^"M@```T/``0
M#X`0G`^`$!S3G!_X@GP_A0@``D`,<!"32'P_N0N3!!PWG``$"!P"4S0<(`"*
M?(`*#&`2F.@``&H,<!"32'P_N0N3!!PWG``"*V```#0Z!DA(>3^Y"!P"6.A?
M&>D(``)`*V````@!`EPWG`9(#'P2F`QX$)Q(8C_9-'X`@$_#/X'H0,`":\(_
MV0@#`D$('@)#;\$!`".+(``WG`UH-',`&#04`$0($P):"!P"60@4`ECH7QYY
M"``"0".+(``WF@OHZ%\0I0@``D`CBR``-YH,".A?$(4(``)`(XL@`#>:"YCH
M7Q!E"``"0".+(``WF@P@Z%\010@``D`CBR``-YH,..A?$"4(``)`(XL@`#>:
M#%#H7Q`%"``"0".+(``WF@NPZ%\/Y0@``D`CBR``-YH,:.A?#\4(``)`(XL@
M`#>:#(#H7P^E"``"0".+(``WF@R8Z%\'=0@``D`,?!*0#'`0G(>`("(CBR``
M-YH,.`QP$)GH7P>E"``"0".+(``WF@S`Z%\'%0@``D`,?!*0#'`0G(>`("(C
MBR``-YH,Z`QP$)GH7P=%"``"0".+(``WF@T`Z%\&M0@``D`,?!*0#'`0G(>`
M("HCBR``-YH+F`QP$)GH7P;E"``"0.@``.HCBR``-YH-(.A?!DT(``)`#'P2
MD`QP$)R'@"`J(XL@`#>:#"`,<!"9Z%\&?0@``D#H``""-'P`&#><`"(,?!*0
M#'`0FB.+(``WF0U(-!@`%.A?%4$(``)`CX`@,@QP$)PWDP`4(XL@`#>:#"`(
M$P)9Z%\%[0@``D`CBR``-YH+Z".+(``WF0U@Z%\%O0@``D!(8C_9-'X`@$_#
M/X'H0,`":\(_V0@#`D$('@)#;\$`@"M@```T/``@#X`0G(^?(+HCBR``-YH,
M(.A?!,T(``)`#'P2D`QP$)R'@"!:#'`0G`^`$!S3G!_XAX`@.@QP$)P/@!`<
MTY,?^#0<`&""?"`2-!,``@QS$ICH```"#&`2F"M@```T/``@#'@0DP^3$H`K
M8```-#P`(`^`$)Q(8C_9-'X`@$_#/X'H0,`""`,"00@>`D-OP0.`:'H_N4A\
M/[DWG``X:'P`2&A@`%#H``!Z2'P`2`^`$)QH?`!`2'P`2#><``AH?`!(2'P`
M4-9\"$(T?``0"GP*'#>3`$A(?`!`#GP2@$A\`%`WG``":'P`4$A\`%"/GE]M
M"``"0#0<`"!H?`!0Z``!HDAU`%!(?`!0-YP_^]9\"$(T?``0"GP*'#><`$@/
M@!"42'P`4#></_'6?`A"-'P`$`I\"APWG`!(#X`0G`N4`I1(?`!0-YP_Y=9\
M"$(T?``0"GP*'#><`$@/@!"<"Y0"E$A\`%`WG#_AUGP(0C1\`!`*?`H<-YP`
M2`^`$)P+E`*4UG4(0C1\`!`*?`H<-YP`2`^4$H!(=0!02'P`4-9\"$(T?``0
M"GP*'#><`$@/@!"<TYP(%-9U"$(T?``0"GP*'#><`$@/E!*`2'P`4#><``)H
M?`!02',`4#0<`)Z*?%X]"``"0$A\/[D/@!"<:'P`.$A\/[D/B!"<:'P`,$A\
M/[D/D!"<:'P`*$A\/[D/F!"<:'P`($A\/[E+G``@#'P2F#1\`%@,?!*02'P`
M.-.<")5(<P`P2'P`*`N3`A1(?``P"X`)DTA\`"`+DP(<"Y0"7`N5"A,,>!"<
M"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(
M?``PTYP+O&A\`#!(?`!`TYP(E4AS`#A(?``P"Y,"%$A\`#@+@`F32'P`*`N3
M`AP+E`)<"Y4*$TA\`"`+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<#'P2
MF`QP$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B52',`0$A\`#@+DP(4
M2'P`0`N`"9-(?``P"Y,"'`N4`EP+E0H32'P`*`N3"A,,<!"<#X`0G`N3"A,C
ME`M0-YPS,PN3"AQH?``@#'`0G#><``@,?!*02'P`0-.<"[QH?`!`2'P`(-.<
M")4,>!"32'P`0`N3`A0,>!"<"X`)DTA\`#@+DP(<"Y0"7`N5"A-(?``P"Y,*
M$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<
MTYP+O`Q\$IA(?``HTYP(E4AS`"`,>!"<"Y,"%$A\`"`+@`F32'P`0`N3`AP+
ME`)<"Y4*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<:'P`,`QP
M$)PWG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B52',`*$A\`"`+DP(42'P`
M*`N`"9,,>!"<"Y,"'`N4`EP+E0H32'P`0`N3"A,,<!"<#X`0G`N3"A,CE`M0
M-YPS,PN3"AQH?``X#'`0G#><``@,?!*02'P`*-.<"[QH?``H2'P`.-.<")5(
M<P`P2'P`*`N3`A1(?``P"X`)DTA\`"`+DP(<"Y0"7`N5"A,,>!"<"Y,*$PQP
M$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+
MO&A\`#!(?`!`TYP(E4AS`#A(?``P"Y,"%$A\`#@+@`F32'P`*`N3`AP+E`)<
M"Y4*$TA\`"`+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<#'P2F`QP$)PW
MG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B52',`0$A\`#@+DP(42'P`0`N`
M"9-(?``P"Y,"'`N4`EP+E0H32'P`*`N3"A,,<!"<#X`0G`N3"A,CE`M0-YPS
M,PN3"AQH?``@#'`0G#><``@,?!*02'P`0-.<"[QH?`!`2'P`(-.<")4,>!"3
M2'P`0`N3`A0,>!"<"X`)DTA\`#@+DP(<"Y0"7`N5"A-(?``P"Y,*$PQP$)P/
M@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\
M$IA(?``HTYP(E4AS`"`,>!"<"Y,"%$A\`"`+@`F32'P`0`N3`AP+E`)<"Y4*
M$TA\`#@+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<:'P`,`QP$)PWG``(
M#'P2D$A\`"#3G`N\:'P`($A\`##3G`B52',`*$A\`"`+DP(42'P`*`N`"9,,
M>!"<"Y,"'`N4`EP+E0H32'P`0`N3"A,,<!"<#X`0G`N3"A,CE`M0-YPS,PN3
M"AQH?``X#'`0G#><``@,?!*02'P`*-.<"[QH?``H2'P`.-.<")5(<P`P2'P`
M*`N3`A1(?``P"X`)DTA\`"`+DP(<"Y0"7`N5"A,,>!"<"Y,*$PQP$)P/@!"<
M"Y,*$R.4"U`WG#,S"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\`#!(
M?`!`TYP(E4AS`#A(?``P"Y,"%$A\`#@+@`F32'P`*`N3`AP+E`)<"Y4*$TA\
M`"`+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<#'P2F`QP$)PWG``(#'P2
MD$A\`#C3G`N\:'P`.`QX$)S3G`B52',`0$A\`#@+DP(42'P`0`N`"9-(?``P
M"Y,"'`N4`EP+E0H32'P`*`N3"A,,<!"<#X`0G`N3"A,CE`M0-YPS,PN3"AQH
M?``@#'`0G#><``@,?!*02'P`0-.<"[QH?`!`2'P`(-.<")4,>!"32'P`0`N3
M`A0,>!"<"X`)DTA\`#@+DP(<"Y0"7`N5"A-(?``P"Y,*$PQP$)P/@!"<"Y,*
M$R.4"U`WG#,S"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(?``H
MTYP(E4AS`"`,>!"<"Y,"%$A\`"`+@`F32'P`0`N3`AP+E`)<"Y4*$TA\`#@+
MDPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<:'P`,`QP$)PWG``(#'P2D$A\
M`"#3G`N\:'P`($A\`##3G`B52',`*$A\`"`+DP(42'P`*`N`"9,,>!"<"Y,"
M'`N4`EP+E0H32'P`0`N3"A,,<!"<#X`0G`N3"A,CE`M0-YPS,PN3"AQH?``X
M#'`0G#><``@,?!*02'P`*-.<"[QH?``H2'P`.-.<")5(<P`P2'P`*`N3`A1(
M?``P"X`)DTA\`"`+DP(<"Y0"7`N5"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*$R.4
M"U`WG#,S"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\`#!(?`!`TYP(
ME4AS`#A(?``P"Y,"%$A\`#@+@`F32'P`*`N3`AP+E`)<"Y4*$TA\`"`+DPH3
M#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<#'P2F`QP$)PWG``(#'P2D$A\`#C3
MG`N\:'P`.`QX$)S3G`B42',`0$A\`#@+DP*32'P`,`N3`IP+E`H32'P`*`N3
M"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AQH?``@#'`0G#><``@,?!*02'P`
M0-.<"[QH?`!`2'P`(-.<")0,>!"32'P`0`N3`I-(?``X"Y,"G`N4"A-(?``P
M"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,
M>!"<TYP+O`Q\$IA(?``HTYP(E$AS`"`,>!"<"Y,"DTA\`$`+DP*<"Y0*$TA\
M`#@+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<:'P`,`QP$)PWG``(#'P2
MD$A\`"#3G`N\:'P`($A\`##3G`B42',`*$A\`"`+DP*3#'@0G`N3`IP+E`H3
M2'P`0`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AQH?``X#'`0G#><``@,
M?!*02'P`*-.<"[QH?``H2'P`.-.<")1(<P`P2'P`*`N3`I-(?``@"Y,"G`N4
M"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`$`,<!"<-YP`
M"`Q\$I!(?``PTYP+O&A\`#!(?`!`TYP(E$AS`#A(?``P"Y,"DTA\`"@+DP*<
M"Y0*$TA\`"`+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<#'P2F`QP$)PW
MG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B42',`0$A\`#@+DP*32'P`,`N3
M`IP+E`H32'P`*`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AQH?``@#'`0
MG#><``@,?!*02'P`0-.<"[QH?`!`2'P`(-.<")0,>!"32'P`0`N3`I-(?``X
M"Y,"G`N4"A-(?``P"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`"@,
M<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(?``HTYP(E$AS`"`,>!"<"Y,"DTA\
M`$`+DP*<"Y0*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<:'P`
M,`QP$)PWG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B42',`*$A\`"`+DP*3
M#'@0G`N3`IP+E`H32'P`0`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AQH
M?``X#'`0G#><``@,?!*02'P`*-.<"[QH?``H2'P`.-.<")1(<P`P2'P`*`N3
M`I-(?``@"Y,"G`N4"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*
M'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\`#!(?`!`TYP(E$AS`#A(?``P
M"Y,"DTA\`"@+DP*<"Y0*$TA\`"`+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+
MDPH<#'P2F`QP$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B42',`0$A\
M`#@+DP*32'P`,`N3`IP+E`H32'P`*`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP7
M0PN3"AQH?``@#'`0G#><``@,?!*02'P`0-.<"[QH?`!`2'P`(-.<")0,>!"3
M2'P`0`N3`I-(?``X"Y,"G`N4"A-(?``P"Y,*$PQP$)P/@!"<"Y,*$R.0C=HW
MG!=#"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(?``HTYP(E$AS
M`"`,>!"<"Y,"DTA\`$`+DP*<"Y0*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(Y"-
MVC><%T,+DPH<:'P`,`QP$)PWG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B4
M2',`*$A\`"`+DP*3#'@0G`N3`IP+E`H32'P`0`N3"A,,<!"<#X`0G`N3"A,C
MD(W:-YP70PN3"AQH?``X#'`0G#><``@,?!*02'P`*-.<"[QH?``H2'P`.-.<
M")1(<P`P2'P`*`N3`I-(?``@"Y,"G`N4"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*
M$R.0C=HWG!=#"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\`#!(?`!`
MTYP(E$AS`#A(?``P"Y,"DTA\`"@+DP*<"Y0*$TA\`"`+DPH3#'`0G`^`$)P+
MDPH3(Y"-VC><%T,+DPH<#'P2F`QP$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX
M$)S3G`B42',`0$A\`#@+DP*32'P`,`N3`IP+E`H32'P`*`N3"A,,<!"<#X`0
MG`N3"A,CD(W:-YP70PN3"AQH?``@#'`0G#><``@,?!*02'P`0-.<"[QH?`!`
M2'P`(-.<")0,>!"32'P`0`N3`I-(?``X"Y,"G`N4"A-(?``P"Y,*$PQP$)P/
M@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\
M$IA(?``HTYP(E0QX$)-(?`!`"Y,"4TA\`"`+DP(4#'@0DTA\`$`+DP(<"Y0"
M7`N5"A-(?``X"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`#`,<!"<
M-YP`"`Q\$I!(?``@TYP+O&A\`"!(?``PTYP(E4AS`"`,>!"<"Y,"4TA\`"@+
MDP(42',`(`QX$)P+DP(<"Y0"7`N5"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.>
M@>,WG#FY"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(
ME4AS`"A(?``@"Y,"4TA\`#`+DP(42',`*$A\`"`+DP(<"Y0"7`N5"A,,>!"<
M"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(
M?``PTYP+O&A\`#!(?`!`TYP(E4AS`#!(?``H"Y,"4TA\`#@+DP(42',`,$A\
M`"@+DP(<"Y0"7`N5"A-(?``@"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*
M'`Q\$I@,<!"<-YP`"`Q\$I!(?``XTYP+O&A\`#@,>!"<TYP(E4AS`#A(?``P
M"Y,"4TA\`$`+DP(42',`.$A\`#`+DP(<"Y0"7`N5"A-(?``H"Y,*$PQP$)P/
M@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\
M`$!(?``@TYP(E4AS`$!(?``X"Y,"4PQX$)P+DP(42',`0$A\`#@+DP(<"Y0"
M7`N5"A-(?``P"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`"@,<!"<
M-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(?``HTYP(E0QX$)-(?`!`"Y,"4TA\`"`+
MDP(4#'@0DTA\`$`+DP(<"Y0"7`N5"A-(?``X"Y,*$PQP$)P/@!"<"Y,*$R.>
M@>,WG#FY"Y,*'&A\`#`,<!"<-YP`"`Q\$I!(?``@TYP+O&A\`"!(?``PTYP(
ME4AS`"`,>!"<"Y,"4TA\`"@+DP(42',`(`QX$)P+DP(<"Y0"7`N5"A-(?`!`
M"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(
M?``HTYP+O&A\`"A(?``XTYP(E4AS`"A(?``@"Y,"4TA\`#`+DP(42',`*$A\
M`"`+DP(<"Y0"7`N5"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*
M'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\`#!(?`!`TYP(E4AS`#!(?``H
M"Y,"4TA\`#@+DP(42',`,$A\`"@+DP(<"Y0"7`N5"A-(?``@"Y,*$PQP$)P/
M@!"<"Y,*$R.>@>,WG#FY"Y,*'`Q\$I@,<!"<-YP`"`Q\$I!(?``XTYP+O&A\
M`#@,>!"<TYP(E4AS`#A(?``P"Y,"4TA\`$`+DP(42',`.$A\`#`+DP(<"Y0"
M7`N5"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`"`,<!"<
M-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E4AS`$!(?``X"Y,"4PQX$)P+
MDP(42',`0$A\`#@+DP(<"Y0"7`N5"A-(?``P"Y,*$PQP$)P/@!"<"Y,*$R.>
M@>,WG#FY"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(?``HTYP(
ME0QX$)-(?`!`"Y,"4TA\`"`+DP(4#'@0DTA\`$`+DP(<"Y0"7`N5"A-(?``X
M"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`#`,<!"<-YP`"`Q\$I!(
M?``@TYP+O&A\`"!(?``PTYP(E4AS`"`,>!"<"Y,"4TA\`"@+DP(42',`(`QX
M$)P+DP(<"Y0"7`N5"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*
M'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E4AS`"A(?``@
M"Y,"4TA\`#`+DP(42',`*$A\`"`+DP(<"Y0"7`N5"A,,>!"<"Y,*$PQP$)P/
M@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\
M`#!(?`!`TYP(E4AS`#!(?``H"Y,"4TA\`#@+DP(42',`,$A\`"@+DP(<"Y0"
M7`N5"A-(?``@"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'`Q\$I@,<!"<
M-YP`"`Q\$I!(?``XTYP+O&A\`#@,>!"<TYP(E4AS`#A(?``P"Y,"4TA\`$`+
MDP(42',`.$A\`#`+DP(<"Y0"7`N5"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.>
M@>,WG#FY"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(
ME4AS`$!(?``X"Y,"4PQX$)P+DP(42',`0$A\`#@+DP(<"Y0"7`N5"A-(?``P
M"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,
M>!"<TYP+O`Q\$IA(?``HTYP(E0QX$)-(?`!`"Y,"4TA\`"`+DP(4#'@0DTA\
M`$`+DP(<"Y0"7`N5"A-(?``X"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*
M'&A\`#`,<!"<-YP`"`Q\$I!(?``@TYP+O&A\`"!(?``PTYP(E4AS`"`,>!"<
M"Y,"4TA\`"@+DP(42',`(`QX$)P+DP(<"Y0"7`N5"A-(?`!`"Y,*$PQP$)P/
M@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\
M`"A(?``XTYP(E$AS`#!(?``H"Y,"DTA\`"`+DP*<"Y0*$PQX$)P+DPH3#'`0
MG`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\
M:'P`,$A\`$#3G`B42',`.$A\`#`+DP*32'P`*`N3`IP+E`H32'P`(`N3"A,,
M<!"<#X`0G`N3"A,CE@E--YP#K`N3"AP,?!*8#'`0G#><``@,?!*02'P`.-.<
M"[QH?``X#'@0G-.<")1(<P!`2'P`.`N3`I-(?``P"Y,"G`N4"A-(?``H"Y,*
M$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(?`!`
MTYP+O&A\`$!(?``@TYP(E`QX$)-(?`!`"Y,"DTA\`#@+DP*<"Y0*$TA\`#`+
MDPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`*`QP$)PWG``(#'P2D`QX
M$)S3G`N\#'P2F$A\`"C3G`B42',`(`QX$)P+DP*32'P`0`N3`IP+E`H32'P`
M.`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3"AQH?``P#'`0G#><``@,?!*0
M2'P`(-.<"[QH?``@2'P`,-.<")1(<P`H2'P`(`N3`I,,>!"<"Y,"G`N4"A-(
M?`!`"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'&A\`#@,<!"<-YP`"`Q\
M$I!(?``HTYP+O&A\`"A(?``XTYP(E$AS`#!(?``H"Y,"DTA\`"`+DP*<"Y0*
M$PQX$)P+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`0`QP$)PWG``(
M#'P2D$A\`##3G`N\:'P`,$A\`$#3G`B42',`.$A\`#`+DP*32'P`*`N3`IP+
ME`H32'P`(`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3"AP,?!*8#'`0G#><
M``@,?!*02'P`.-.<"[QH?``X#'@0G-.<")1(<P!`2'P`.`N3`I-(?``P"Y,"
MG`N4"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'&A\`"`,<!"<
M-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E`QX$)-(?`!`"Y,"DTA\`#@+
MDP*<"Y0*$TA\`#`+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`*`QP
M$)PWG``(#'P2D`QX$)S3G`N\#'P2F$A\`"C3G`B42',`(`QX$)P+DP*32'P`
M0`N3`IP+E`H32'P`.`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3"AQH?``P
M#'`0G#><``@,?!*02'P`(-.<"[QH?``@2'P`,-.<")1(<P`H2'P`(`N3`I,,
M>!"<"Y,"G`N4"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'&A\
M`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E$AS`#!(?``H"Y,"
MDTA\`"`+DP*<"Y0*$PQX$)P+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<
M:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\`$#3G`B42',`.$A\`#`+
MDP*32'P`*`N3`IP+E`H32'P`(`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3
M"AP,?!*8#'`0G#><``@,?!*02'P`.-.<"[QH?``X#'@0G-.<")1(<P!`2'P`
M.`N3`I-(?``P"Y,"G`N4"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L
M"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E`QX$)-(
M?`!`"Y,"DTA\`#@+DP*<"Y0*$TA\`#`+DPH3#'`0G`^`$)P+DPH3(Y8)33><
M`ZP+DPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3G`N\#'P2F$A\`"C3G`B42',`
M(`QX$)P+DP*32'P`0`N3`IP+E`H32'P`.`N3"A,,<!"<#X`0G`N3"A,CE@E-
M-YP#K`N3"AQH?``P#'`0G#><``@,?!*02'P`(-.<"[QH?``@2'P`,-.<")1(
M<P`H2'P`(`N3`I,,>!"<"Y,"G`N4"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.6
M"4TWG`.L"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(
ME$AS`#!(?``H"Y,"DTA\`"`+DP*<"Y0*$PQX$)P+DPH3#'`0G`^`$)P+DPH3
M(Y8)33><`ZP+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\`$#3
MG`B42',`.$A\`#`+DP*32'P`*`N3`IP+E`H32'P`(`N3"A,,<!"<#X`0G`N3
M"A,CE@E--YP#K`N3"AP,?!*8#'`0G#><``@,?!*02'P`.-.<"[QH?``X2'P_
MN0^`$),,>!"<"Y,*$TA\/[D/DQ*`2'P_N0^($)-(?`!`"Y,*$TA\/[D/DQ*(
M2'P_N0^0$)-(?``X"Y,*$TA\/[D/DQ*02'P_N0^8$)-(?``P"Y,*$TA\/[D/
MDQ*82'P_N4N3`"!(?``H"Y,*$TA\/[EKDP`@-'X`@$_#/X'H0,`""`,"00@>
M`D-OP0"`:'H_N4AS/[DCBDSH-YP&`PY\$H!(<S^Y(X[-^3><%Q,.?!*(2',_
MN2.6@Q<WG#G\#GP2D$AS/[DCD@(&-YPH[`Y\$IA(<S^Y(Y@(>S><`^%J?``@
M2'P_N6N``"A(?#^Y:X``,$A\/[EK@`"X-'X`@$_#/X'H0,`":\(_V0@#`D$(
M'@)#;\$`@&AZ/[EH>3^Q:'@_J4A\/[E+DP`H2'P_J=><"&,+DPH<#'P2D$A\
M/[E+DP`H#'`0G(I\@")(?#^Y2YP`,#>3``)(?#^Y:Y,`,$AS/[D,<!"<:GP`
M*$A\/[E+DP`P2'P_J=.<&%T+DPH32'P_N6N3`#!(?#^Y2YP`N(>`(<I(?#^Y
M2YP`N)><`(`,?!*8#'@0DTA\/ZF*?$`*2'P_J0Q\$IA(?#^Y-Y,`.$A\/[E+
MG`"X"Y,*'`QX$),('`):2'D_L0@3`ECH7A3)"``"0$AS/ZD,>!"<"Y,$'&A\
M/ZD,>!"32'P_L0I\"AQH?#^Q2'P_N4N3`+@,>!"<"Y,*$TA\/[EKDP"X2'P_
MN4N3`+@T'`"`BGPA$DAZ/[GH7AIM"``"0.@``'I(?#^Y-YP`.`@<`EI(>3^Q
M-!@`@.A>$^$(``)`2'P_L3><`(!H?#^Q2'P_J3></X%H?#^I2'H_N>A>&>4(
M``)`2',_J30<`'Z"?%]E"``"0$A\/[DWG``X2',_J0@<`EI(>3^Q"!,"6.A>
M$SD(``)`2',_N4A\/ZEJ?`"X2&(_V31^`(!/PS^!Z$#``FO"/]D(`P)!"!X"
M0V_!`(!H>C^Y:'D_L4AZ/['H7AD%"``"0$A\/[$/@!"<TYP8^-.3&_A(?#^Y
M#Y,2`$A\/[DWDP`"2'P_L0^`$)S3G!GPTYP;^`Y\$@!(?#^Y-Y,`!$A\/[$/
M@!"<TYP:Z-.<&_@.?!(`2'P_N3>3``9(?#^Q#X`0G-.<&_@.?!(`2'P_N3>3
M``A(?#^Q#X@0G-.<&/C3G!OX#GP2`$A\/[DWDP`*2'P_L0^($)S3G!GPTYP;
M^`Y\$@!(?#^Y-Y,`#$A\/[$/B!"<TYP:Z-.<&_@.?!(`2'P_N3>3``Y(?#^Q
M#X@0G-.<&_@.?!(`2'P_N3>3`!!(?#^Q#Y`0G-.<&/C3G!OX#GP2`$A\/[DW
MDP`22'P_L0^0$)S3G!GPTYP;^`Y\$@!(?#^Y-Y,`%$A\/[$/D!"<TYP:Z-.<
M&_@.?!(`2'P_N3>3`!9(?#^Q#Y`0G-.<&_@.?!(`2'P_N3>3`!A(?#^Q#Y@0
MG-.<&/C3G!OX#GP2`$A\/[DWDP`:2'P_L0^8$)S3G!GPTYP;^`Y\$@!(?#^Y
M-Y,`'$A\/[$/F!"<TYP:Z-.<&_@.?!(`2'P_N3>3`!Y(?#^Q#Y@0G-.<&_@.
M?!(`2'P_N3>3`"!(?#^Q2YP`(-.<&/C3G!OX#GP2`$A\/[DWDP`B2'P_L4N<
M`"#3G!GPTYP;^`Y\$@!(?#^Y-Y,`)$A\/[%+G``@TYP:Z-.<&_@.?!(`2'P_
MN3>3`"9(?#^Q2YP`(-.<&_@.?!(`2&(_V31^`(!/PS^!Z$#``FO"/]D(`P)!
M"!X"0V_!`0!H>C^Y:'D_L4A\/[%+G``H#'P2F$A\/[%+G``P#'P2D`QX$)S3
MG!N#TYP;^FA\`"!(?#^Q-Y,`.$A\`"`+DPH3-!P_`0Y\$@!(?``@-YP``FA\
M`"!(<P`@-!P`<(I\0*I(?#^Q-Y,`.$A\`"`+DPH32'P`()><`(`($P):-!D`
M``@<`ECH7@81"``"0$AZ/['H7A-E"``"0$A\/[$WG``X"!P"6C09```T&`!P
MZ%X%P0@``D#H``!22'P_L3>3`#A(?``@"Y,*$TA\`""7G`!P"!,"6C09```(
M'`)8Z%X%80@``D`,<!"<TYP8^-.3&_A(?#^Q8Y,`J`QP$)S3G!GPTY,;^$A\
M/[%CDP"J#'`0G-.<&NC3DQOX2'P_L6.3`*P,<!"<TY,;^$A\/[%CDP"N#'@0
MG-.<&/C3DQOX2'P_L6.3`+`,>!"<TYP9\-.3&_A(?#^Q8Y,`L@QX$)S3G!KH
MTY,;^$A\/[%CDP"T#'@0G-.3&_A(?#^Q8Y,`MDAZ/[E(>3^QZ%\8-0@``D!(
M8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$!`&A@`"`,8!*8Z%X,D0@`
M`D`,?!*0#'`0G(>`(#(,<!":Z%X$P0@``D`,?!*8#'@0G`^`$)QH?``@2'P`
M($AB/]DT?@"`3\,_@>A`P`)KPC_9"`,"00@>`D-OP0$`:&0`8&AZ/[EH8``H
M:&``("M\W_\T/`\8-',`,#04`#`($P):"!P"60@4`ECH7@G1"``"0`Q@$I`,
M8!*8Z``!XDAZ`"CH7A/9"``"0&A\`"!(?``@AX`@&DA\`"`/@!`<TYP?^(^`
M(")(>@`H2'D_N>A>$_$(``)`Z``!4DAZ`"!(>3^YZ%X&@0@``D"/@"$J2'H_
MN>A>!0$(``)`"!P"1"M@```(`0)<-YP`&`^`$)P('`):Z%X$P0@``D`+A`H$
M2'H`(.A>!*$(``)`"X0*'#><``0('`):Z%X'&0@``D`,?!*0*V````@!`EPW
MG``8#X`0DTA\`"!KW#^9#'`0FB.+(``WF0O82'@_N0@3`E?H7@3I"``"0$AZ
M`"@,<!"9Z%X2D0@``D`,>!"<-YP``@Q\$I@,>!"<UGP(0C1\`!`*?`H<-YP`
M(`^`$)QH?``H2'P`*`^`$!S3G!_XCX`]O0@``D!(8C_92&0`8#1^`(!/PS^!
MZ$#``FO"/]D(`P)!"!X"0V_!/X`KPP``-#X#@"AD``!H)`(P:'H_N6A@`&AH
M8`!@:&``6"M\W_\T/`_0-',`@#04`"`($P):"!P"60@4`ECH7@:A"``"0"M\
MW_\(`0)<-YP/@#1S`*`T%``P"!,"6@@<`ED(%`)8Z%X&40@``D`CBR``-YP/
M&&A\`-`CBR``-YP/*&A\`-@CBR``-YP..&A\`.`CBR``-YP/0&A\`%`CBR``
M-YP..&A\`$AH8`!`:&``.&A@`#`,8!*0(XL@`#>:"YCH7@_1"``"0&A\`%A(
M?`!8AX`@<DA\`%@/@!`<TYP?^(>`(%)(>@!8Z%\:]0@``D!(>@!8Z%X`$0@`
M`D`B9```-G,"*`AS"A,.?!*`Z``.JNA?&>T(``)`:'P`.$A\`#B/@"#B:&``
M>.@``&)(>@!@Z%X.\0@``D!H?`!82'P`6(>`(!I(>@!8Z%T?;0@``D!H?``X
M2'P`>#><``)H?`!X2'P`.(^`(%I(?`!XUGP(0C1\`!`*?`H<-YP`P`^`$)QH
M?`!@2'P`8`^`$!S3G!_XCX`_+0@``D!(?``XCX`@&B.+(``WG`]0:'P`..@`
M`-I(?``X:'P`<.@``)KH7@#A"``"0`^`$)-(?`!P#X`0'-.<'_C7G`@A"Y,*
M'`^`$%S3G!OP"!P"4S0<$``+DP(<CX`@$DAS`'`T'`"^#GP2`$A\`'`WG``"
M:'P`<$A\`'`/@!`<TYP?^(^`/ST(``)`:&``>.@``?)(>@!@Z%X,^0@``D!H
M?`!82'P`6(>`(:HT&@``Z%X!$0@``D`/@!"<"!P"6NA=&[4(``)`"!P"6NA=
M'_T(``)`2'H`6`@<`EGH0!-$"``"0(^`(3(T&@``Z%X`F0@``D`/@!"<"!P"
M6NA=&ST(``)`"!P"6NA='X4(``)`2Y,`(".'(``+DP(3(X(``()\('(T&@``
MZ%X`(0@``D`/@!"<"!P"6NA=&L4(``)`"!P"6NA='PT(``)`2Y,`(".'(``+
MDP(3(X4``(I\($)(>@!8-!D`!.A=&Z4(``)`CX`@&DAZ`%CH71OE"``"0&A\
M`&A(?`!X-YP``FA\`'A(?`!HCX`@6DA\`'C6?`A"-'P`$`I\"APWG`"0#X`0
MG&A\`&!(?`!@#X`0'-.<'_B/@#V="``"0&A@`'CH``'"-!H``.A='LT(``)`
M#X`0G`@<`EKH71EM"``"0`@<`EKH71VU"``"0$AZ`%@('`)9Z$`0_`@``D"/
M@"$R-!H``.A='E4(``)`#X`0G`@<`EKH71CU"``"0`@<`EKH71T]"``"0$N3
M`"`CAR``"Y,"$R."``""?"!R-!H``.A='=T(``)`#X`0G`@<`EKH71A]"``"
M0`@<`EKH71S%"``"0$N3`"`CAR``"Y,"$R.%``"*?"!"2'H`6#09``3H71E=
M"``"0(^`(!I(>@!8Z%T9G0@``D!H?`!H2'P`>#><``)H?`!X2'P`:(^`(%I(
M?`!XUGP(0C1\`!`*?`H<-YP`<`^`$)QH?`!82'P`6`^`$!S3G!_XCX`]S0@`
M`D!(>@!HZ%T:%0@``D`('`)$2'H`4.A=&?4(``)`"X0*!$AZ`#CH71G5"``"
M0`N$"@1(>@!(Z%T9M0@``D`+A`H<-YP(``Q\$I`,<!"<"!P"6NA='!T(``)`
M:'P`,"M@```(`0)<-YP`$`^`$)-(?`!0:]P_F4A\`#AKW#^12'H`,".+(``W
MF0]@2'@`:`@3`E?H71G="``"0$AZ`#`T&0/:Z%T5_0@``D`CBR``-YH.`.A>
M!O$(``)`:'P`6$A\/[D/@!"$2'H`6.A=%VT(``)`"`0"6@@<`EGH7A*1"``"
M0&A\`$!(?`!`CX`@$DA\/[D/@!"<:'P`0.A>`3T(``)`CX`DJDAZ`$`T&0``
MZ%T;!0@``D!H?``H2'P`*(>`)'(T'``$:]P_F4AZ`"@T%S__-!@_W>A='/4(
M``)`-'P"`$AZ`"@('`)9-!@`#.A=&F4(``)`0'P"`-.<&_B/@"&"0'P"`M.3
M&_@T'`"&BGPA8D!\`@33DQOX-!P`@HI\(4)`?`(&TY,;^#0<`(:*?"$B0'P"
M"-.3&_@T'`"0BGPA`D!\`@K3DQOX-!P`BHI\(.(T'``$:]P_F4AZ`"@T%S__
M-!@_C>A=&]4(``)`-'P"`$AZ`"@('`)9-!@`4NA=&44(``)`*V````@!`EPW
MG``0#X`0DS1\`@!KW#^92'P`2&O</Y%(>@`P(XL@`#>9#WA(>``P"!,"5^A=
M%LT(``)`Z``#&C1\`4`('`):Z%\"/0@``D#H```R-'P!0#1S`@`('`):"!,"
M64AX`"#H7P,%"``"0#1\`@!(>@`H"!P"62,$``#H71@U"``"0&A\`"!(?``@
MAX!??0@``D!(>@`HZ%T:/0@``D`CA```-Y,!\#1\`!`*?`H<-',!0`@<`EH(
M$P)9Z%\*;0@``D`,8!*8Z```J@QX$)S7G`@A-'0`Z`N4"A0,>!"5(F0``#1\
M`!`*?`H<"KP*'#><`?`/@!`<TYP;^`@<`E,(%`):(XL@`#>9#Y@($P)8Z%T5
M#0@``D`,>!"<-YP``@Q\$I@,>!"3-!P`)HI\7S4(``)`8&`!."M@```T/``0
M#X`0DS1\`.AKW#^92'P`2&O</Y%(>@`P(XL@`#>9#WA(>``P"!,"5^A=%%T(
M``)`Z```JB.+(``WF@P@(XL@`#>9#6#H7@'I"``"0"M@```(`0)<-YP`$`^`
M$(3H71)U"``"0&O</YE(?`!(:]P_D4AZ`#`CBR``-YD/J$AX`#`(!`)7Z%T3
MI0@``D`CBR``-YH+F$AY`##H7@%!"``"0$AZ`##H7PPM"``"0$A\`#`B9```
M-G,"*`AS"A,.?!*`("0``#0A`B@(80H!#"`0G$AB/]DH9```2"0",#1^`(!/
MPS^!Z$#``FO"/]D(`P)!"!X"0V_!`8!H9`$`:'H_N6AY/[$,8!*82'H_N>A=
M#K4(``)`:'P`*$A\`"B'@"*2Z``"$DA\`"`WG``F"!P"6B.+(``WF0O0Z%T1
M'0@``D"'@"'22'P`(#><`"8('`):(XL@`#>9#\CH71#="``"0(>`(9)(>C^Y
MZ%T0_0@``D`('`)$2'P`(#><`"8('`):Z%T0S0@``D`+A`H<-YP`!`Q\$I`,
M<!"<"!P"6NA=$S4(``)`#'P2F$A\`"`WDP`F#'@0FB.+(``WF0_02'@_N0@3
M`E?H71$E"``"0#1\`#`,>!":"!P"6>A`!.0(``)`AY\@6DAS`%`CAR``"Y,"
M$R."``"*?"`R2'P_L8>`("(,>!":-!D``NA?';4(``)`Z```$@QX$)KH714=
M"``"0`QX$)KH70]E"``"0`Q@$IA(>@`HZ%T/A0@``D!H?``@2'P`((^`/;4(
M``)`2'H`*.A=#FT(``)`2'P_N8>`(!)(>C^YZ%T2Q0@``D!(8C_92&0!`#1^
M`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!`(!H>C^Y2'H_N>A>#[D(``)`#'P2
MF`QX$)KH7@Z1"``"0`Q\$I#H7A=Q"``"0(>`(*I(?#^YAX`@FDA\/[D/@!`<
MTYP?^(>`('H,<!":(XL@`#>9#T#H70]E"``"0`@<`E,,<!"<BGP@.DAZ/[DT
M&0`"Z%\;Q0@``D`,>!":-!D``.A?&Z4(``)`2&(_V31^`(!/PS^!Z$#``FO"
M/]D(`P)!"!X"0V_!`0!H9``@:'D_L30:``#H70_%"``"0`^`$)P('`):Z%T*
M90@``D`('`):Z%T*;0@``D`/@!"<#X@0A#0:``#H70]E"``"0`^`$)P('`):
MZ%T*!0@``D`('`):Z%T230@``D`/@!`<TYP;^&"<`#`T&@``Z%T._0@``D`/
M@!"<"!P"6NA="9T(``)`"!P"6NA=":4(``)`#X`0G`^($(0T&@``Z%T.G0@`
M`D`/@!"<"!P"6NA="3T(``)`"!P"6NA=$.4(``)`#X`0G$N<`"#3G!D7TYP;
M\&2<`#0T&@``Z%T.)0@``D`/@!"<"!P"6NA=",4(``)`"!P"6NA=",T(``)`
M#X`0G`^($(0T&@``Z%T-Q0@``D`/@!"<"!P"6NA="&4(``)`"!P"6B.+(``W
MF0XX-!@``.A=")4(``)`:)P`.#0:``#H70U5"``"0`^`$)P('`):Z%T']0@`
M`D`('`):Z%T'_0@``D`/@!"<#X@0A#0:``#H70SU"``"0`^`$)P('`):Z%T'
ME0@``D`('`):Z%T.'0@``D`/@!"<:)P`0#0:``#H70R5"``"0`^`$)P('`):
MZ%T'-0@``D`('`):Z%T'/0@``D`/@!"<#X@0G`Q\$I@T&@``Z%T,+0@``D`/
M@!"<"!P"6NA=!LT(``)`"!P"6NA=#/4(``)`#X`0G(>`(&HT&@``Z%T+S0@`
M`D`/@!"<"!P"6NA=!FT(``)`"!P"6NA=#)4(``)`#X`0G$N<`-@,?!*0Z```
M`@Q@$I`,<!"<#'@0DVI\`$@T&@``Z%T+/0@``D`/@!"<"!P"6NA=!=T(``)`
M"!P"6NA=!>4(``)`#X`0G`^($)QK@`!0-!H``.A="M4(``)`#X`0G`@<`EKH
M705U"``"0`@<`EKH705]"``"0`^`$)P/B!"<:X``6#0:``#H70IM"``"0`^`
M$)P('`):Z%T%#0@``D`('`):Z%T%%0@``D`/@!"<#X@0A#0:``#H70H-"``"
M0`^`$)P('`):Z%T$K0@``D`('`):Z%T)E0@``D`/@!"<:)P`8$AB/]E(9``@
M-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$`@&AY/[$T&@``Z%T)70@``D`/
M@!"<"!P"6NA=`_T(``)`"!P"6C09/__H70G]"``"0#0:``#H70D%"``"0`^`
M$)P('`):Z%T#I0@``D`('`)3(XL@`#><#^`/@!"<"!,"6@@<`EDT&```Z%T%
MO0@``D!(8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$!`&AY/[%H8``@
M-!H``.A="#4(``)`#X`0G`@<`EKH70+5"``"0`@<`EKH708="``"0`@<`E,T
M'``"#GP2`".+(``WF@OHZ%T3?0@``D`,?!*8#'@0G(>`($H,>!"<#X`0'-.3
M'_@T'`!BBGP@(@QX$)PWG``"#X`0'-.<'_B'@"`*Z%X)Z0@``D`T&@``Z%T'
M-0@``D`/@!"<"!P"6NA=`=4(``)`"!P"6B.+(``WF0_H-!@``C07`!;H702]
M"``"0&A\`$A(?`!(AX`C8DA\`$@/F!"<2YP`,&A\`$`T'``":'P`*.@``@HT
M&@``Z%T&=0@``D`/@!"<"!P"6NA=`14(``)`"!P"4TA\`"@WG#__"!,"6DAY
M`$`('`)8-!<``.A=!:T(``)`:'P`.$A\`#B'@"&B*V`@`#0\!F`/@!"32'P`
M*-><"$(+DPH<#X`0G&A\`'!(?``X#X`0G`^0$),T'`@`"Y,"'(>`(")(?``X
M#X`0G`^8$)QH?`!HZ```@C0:``#H705%"``"0`^`$)P('`):Z%T?X0@``D`(
M'`)32'P`.`^`$)P($P):"!P"6308```T%P`$Z%T$O0@``D!H?`!H2'H`<$AY
M`&CH70'U"``"0(^`(%I(?``@-YP``FA\`"!(?``H-YP``FA\`"@K8"``-#P&
M6`^`$)-(?``HBY-]Q0@``D`K8"``-#P&6`^`$)PWDS__2'P`((I\(+HT'``"
M:'P`*.@``'(T&@``Z%T#[0@``D`/@!"<"!P"6NA='HD(``)`"!P"6DAY`$#H
M70`M"``"0&A\`#!(?``H-YP``FA\`"@K8"``-#P&6`^`$)-(?``HBY-_70@`
M`D`T&@``Z%T#10@``D`/@!"<"!P"6NA='>$(``)`"!P"6B.+(``WF0_X-!@`
M`C07``KH70#-"``"0&A\`$A(?`!(AX`A,C0:``#H70*]"``"0`^`$)P('`):
MZ%T=60@``D`('`)32'P`2`^8$)P/@!"<"!,"6@@<`EDCBS``-Y@``.A='ND(
M``)`2'P`2`^8$)P/@!"<#Y`0DR.```@+DP(<AX`@<C0:``#H70']"``"0`^`
M$)P('`):Z%T<F0@``D`('`)32'P`2`^8$)P/@!"<"!,"6@@<`EGH703]"``"
M0#0:``#H70&%"``"0`^`$)P('`):Z%T<(0@``D`('`):(XLP`#>9`!`T&``"
M-!<`"NA='PD(``)`:'P`2$A\`$B'@"%J#&`2D".+(``WF@NPZ%T,I0@``D`,
M?!*0#'`0G(>`(((T&@``Z%T`O0@``D`/@!"<"!P"6NA=&UD(``)`"!P"4TA\
M`$@/F!"<#X`0G`@3`EH('`)9#'`0F.A='/$(``)`Z```HC0:``#H70`U"``"
M0`^`$)P('`):Z%T:T0@``D`('`)32'P`2`^8$)P/@!"4*V`@``@!`EPWG`9@
M#X`0G`^`$)P($P):"!0"60@<`ECH70:E"``"0#0:``#H71^)"``"0`^`$)P(
M'`):Z%T:*0@``D`('`):Z%T=<0@``D`/@!(`-!H``.A='S$(``)`#X`0G`@<
M`EKH71G1"``"0`@<`EKH70"="``"0`^`$H`CBR``-YH+F.A="HT(``)`"!P"
M4RM@(``(`0)<-YP&4`^3$H`K8"``"`$"7#><!E`/@!"<CX`BZBM@(``T/`9@
M#X`0G`@<`EKH7QB)"``"0`@<`E,K8"``"`$"7#><!E`/DQ*`2'P`2`^8$)P/
M@!"<#Y`0DS0<"``+DP(<AX`@*DA\`$@/F!"<#X`0G`^8$)QH?`!@Z```BC0:
M``#H71VI"``"0`^`$)P('`):Z%T820@``D`('`)32'P`2`^8$)P/@!"<"!,"
M6@@<`EDT&```-!<`!.A='1D(``)`:'P`8"M@(``T/`9@#X`0G$AZ`&`('`)9
MZ%T;^0@``D!H?``H*V`@``@!`EPWG`9@#X`0G`^`$)QH?`!82'P`2`^8$)P/
M@!"<#Y`0DS0<"``+DP(<AX`@*DA\`$@/F!"<#X`0G`^8$)QH?`!0Z```BC0:
M``#H71Q!"``"0`^`$)P('`):Z%T6X0@``D`('`)32'P`2`^8$)P/@!"<"!,"
M6@@<`EDT&```-!<`!.A=&[$(``)`:'P`4".+,``WF@`82'D`6$AX`%!(=P`H
MZ%T=D0@``D`K8"``-#P&4`^`$)P('`):-!D#VNA=%?D(``)`:'P`*$A\`"B'
M@""22',`*#0<`"*"?"!Z2'P`*(>?(&HK8"``-#P&8`^`$)P/@!"4*V`@`#0\
M!E`/@!"3(XLP`#>:`'@(%`)9"!,"6$AW`"CH71RI"``"0$AB/]DT?@"`3\,_
M@>A`P`)KPC_9"`,"00@>`D-OP0"`-!H``.A=&E$(``)`#X`0G`@<`EKH713Q
M"``"0`@<`EKH70`U"``"0#0:``#H71H!"``"0`^`$)P('`):Z%T4H0@``D`(
M'`)3(XLP`#><`4@/@!"4(XL@`#><#CAKW#^9:\`_D0@3`EHCBS``-YD!&`@4
M`E@CBR``-Y<...A=&\$(``)`2&(_V31^`(!/PS^!Z$#``FO"/]D(`P)!"!X"
M0V_!`0!H>C^Y:'D_L6AX/ZDT?#^Y-',_L31T/ZD('`):"!,"60@4`ECH71=)
M"``"0".+,``WG`%@#X`0E".+,``WG`%H#X`0DR.+,``WG`%H#X`0G`@4`EH(
M$P)9"!P"6.A`"/@(``)`-!H``.A=%D$(``)`#X`0'-.<'_B/@"#ZZ%T3&0@`
M`D`('`)3*V`@``@!`EPWG`9(#Y,2@"M@(``(`0)<-YP&2`^`$)R/@"`2-!H`
M`NA=%?$(``)`*V`@`#0\!D@/@!"<"!P"6NA=&:$(``)`-!H``.A=%VD(``)`
M#X`0G`@<`EKH71()"``"0`@<`EKH71,1"``"0`^`$@`T&@``Z%T7$0@``D`/
M@!"<"!P"6NA=$;$(``)`"!P"6NA=&)D(``)`"!P"4PY@$!S3G!OXUY\</].<
M&_@.?!(`-!H``.A=%I$(``)`#X`0G`@<`EKH71$Q"``"0`@<`EKH71@9"``"
M0`@<`E,.8!`<TYP;^->?'!_3G!OX#GP2`$A\/[DWG``*:'P`*#0<``!H?``@
M2'P`($A]`"@/W!*!#]T2B2_!$!8RP*H7,`!(%C+V#A<T`0`"8&$`,".+,``W
MG`%P+X`0%C+V#`\P`"0@Z````F!@`#!`<P`P-!P``@N3`IS3G!OXCX`@&B./
M$``WF@4PZ%T7,0@``D!(?#^Y-YP`"M><"$(('`):Z%T080@``D`('`)3*V`@
M``@!`EPWG`9@#Y,2@"M@(``(`0)<-YP&8`^`$)-(?#^Q#X`0G`Y\$H`K8"``
M"`$"7#><!F`/@!"<-Y,`"".+,``WG`%0#GP2@"M@(``(`0)<-YP&8`^`$)PW
MDP`0*WSO_P@!`EPWG`)X#GP2@"M@(``(`0)<-Y,&6#0<``8.?!*`*V`@``@!
M`EPWG`9@#X`0DRM@(``(`0)<-YP&6`^`$)S7G`A""Y,*$R.+,``WG`%8#GP2
M@"M@(``(`0)<-YP&6`^`$)PWDP`"*V`@``@!`EPWG`98#Y,2@#0<``(,?!*0
MZ```LBM@(``T/`9@#X`0E"M@(``T/`98#X`0DPQP$)P+DPH<EY,``@@3`ES7
MG`O>"GP$'-><"$(+E`H42',_L0QP$)S7G`A""Y,*'`^`$)P.G!*`#'`0G#><
M``(,?!*02',_N0QP$)R+DW\M"``"0"M@(``T/`9@#X`0E$AS/[DK8"``-#P&
M6`^`$)P+DPH<EY,``@@3`ES7G`O>"GP$'-><"$(+E`H<#X`2@"M@(``T/`9(
M#X`0E4AS/[DK8"``-#P&6`^`$)P+DPH<-Y,__RM@(``T/`9@#X`0E".+,``W
MG`&`#X`0G&O`/YD(%0):"!P"60@3`E@(%`)7Z%T-20@``D`,?!*8#'@0G(^`
M(#(K8"``-#P&2`^`$)P('`):Z%T3(0@``D`,?!*8*V`@`#0\!D@/@!"<"!P"
M6NA=$"D(``)`(XL@`#>:#`CH71Q!"``"0(^`(+(K8"``-#P&4`^`$)R/@"!"
M(XL@`#>:"YCH71OY"``"0`@<`E,K8"``"`$"7#><!E`/DQ*`*V`@`#0\!E`/
M@!"<AX`@*BM@(``T/`90#X`0G`@<`EKH7QYQ"``"0"M@(``T/`9(#X`0G`@<
M`EKH70XY"``"0.A=$6D(``)`#'@0G$AB/]DT?@"`3\,_@>A`P`)KPC_9*V``
M`$@\!=B'@"`(-!<```^`$)=+PC_9Z!T,&0@``D`(``)`Z$#``FO"/]EOR0$`
M"!H"26O(/PD(&0)(:\<_$0@8`D=KQC\9:\4_(6O$/RD($P)$:],_P>A="(EK
MPS\Q"`0"4RM@``!(/`7@*V```$@F!>@(W`0<TX4?HH2@(%`T`P``#,,@E@@3
M`D0T8P`""`D"6@@(`ED(!P)8Z^``V`@?`D*(HS^U"`0"4TO"/ME+R#\)2\<_
M$4O&/QE+Q3\A2\0_*4O#/S'H0,``3\D_`6O"/]D(&0)82\(_V0@:`EDT&@`&
MZ!T.(0@``D`(``)`:\(_V0@9`EA+PC_9"!H"630:``;H'0D!"``"0`@``D#'
MUL`2UL`<'@[($),.P!"6ZL#``&O"/]%KPC_9;\0`@&O#/XF'7R`0:],_P30<
M'_Z#7(`B"!H"7$O"/UE+PS^)Z$#``$_$/X''VM_-"!H"0RM@``!(/070U&`<
M'@Q@$)HW5``@BIT_G0@:`EPK8```2#<%P`[@$)R'@"`X(L</@0^H$)H.X!"6
M#&@0F>O_'MT('P)"Z!\?-0Q@$)H.D1"42I\`0`K?`APBH`T!@Y4@*#:8`$`.
MF1"?-I@_^0K?`AR+E3[=-!H__]/U&Y;3_!N_UYP)2M/V&?#3]!O_UM8)>]:4
M"A`*M`)4"Y0"5`K4`E32G!GPAX`@$-:T"$+6GQXQUK0(0@JX"A0K8```2#P%
MR#:4`!`/E!*`#[D0E0^5$HC7GQP>Z!\>K0[\$H`K?___:\(_V6_%`0!KQ#\)
M:\,_$30C#@`,>1"%Z%\=E0@%`EHT&C__Z%\=?0@<`D2`G"!8-&,_^0@%`E;K
M_QTE"!\"0DQE/_GH7QT]"`4"6C0:/__H7QTE"!P"1(B</[4(!0)62\(^V4O$
M/PE+PS\1Z$#``$_%/P%KPC_9-]X`@$O"/UGH0,``-]X_@>A`P`)KPC_9;\0`
M@&O3/\$($P)$Z%T-N0@``D!+PC]9"`0"4^A`P`!/Q#^!``'J.@`!Z9(``>?:
M``'I2@`"``$`````<&5R;'AS:2YC````1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R```!Z/(O<')O8R]S96QF+V5X90``+P```#H````O<')O8R\E:2\E
M<P!E>&4`4$%27U1%35``````4$%27U!23T=.04U%`````"X````E<R5S)7,`
M`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?
M1$5"54<```!005)?0T%#2$4```!005)?05)'0P````!005)?05)'5E\P``!0
M05)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-
M4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%2
M7T-,14%./0``,0```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`````$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!0
M051(`````$193$1?3$E"4D%265]0051(```````````!=M@``7;H``%V\``!
M=P```7<(``%W'%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4````79T``%W
M.``!=T```7=(``%W4``!=QQ#.EQ414U0`"]T;7````````%W;``!=W0``77H
M``%W'%5315(`````55-%4DY!344`````<&%R+0````!365-414T``"5S)7,E
M<R5S`````"5S)7-C86-H92TE<R5S```E,#)X`````"5S)7-T96UP+25U)7,`
M```N+@``)7,O)7,``````>>R05)'5@`````8````<&5R;``````P````)7,Z
M(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H```!);G1E<FYA;',Z
M.E!!4CHZ0D]/5````````>A*+64``"TM`````>D"``'G^D'/____@`````'G
MN@````!P87(N<&P``",A+W5S<B]B:6XO<&5R;`H*979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC
M("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@
M8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3D*"FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@
M("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3
M<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D
M<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M
M9&ER("1P87)?=&5M<#L*("`@(')M9&ER("1T;W!D:7(["@H@("`@:68@*"UD
M("1P87)?=&5M<"D@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@
M=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@
M("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES
M86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N
M9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@
M8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL
M97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H*("`@
M("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%
M35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&
M1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@
M("`@*3L*"B`@("`@("`@(R!"96-A=7-E('1H92!P87)?=&5M<"!D:7)E8W1O
M<GD@:7,@9V]I;F<@=&\@8F4@9&5L971E9"!I;B!A"B`@("`@("`@(R!B86-K
M9W)O=6YD('!R;V-E<W,L('1H92!P87)E;G0@<')O8V5S<R!I9"!M87D@8F4@
M<F5U<V5D(&)E9F]R92!T:&4*("`@("`@("`C(&)A8VMG<F]U;F0@<')O8V5S
M<R!C;VUP;&5T97,N("!4;R!E;G-U<F4@=&AA="!T:&4@=&5M<&]R87)Y"B`@
M("`@("`@(R!D:7)E8W1O<GD@9&]E<R!N;W0@9V5T(')E=7-E9"!W:&EL92!I
M="!I<R!B96EN9R!D96QE=&5D+"!T<GD@=&\*("`@("`@("`C(')E;F%M92!I
M="!T;R!A(&YA;64@=&AA="!I<R!R96QA=&5D('1O('1H92!T96UP;W)A<GD@
M<V-R:7!T(&9I;&4N"@H@("`@("`@(&UY("1T;7!N86UE(#T@*$9I;&4Z.E-P
M96,M/G-P;&ET<&%T:"@D=&UP+3YF:6QE;F%M92DI6S)=.R`C(&9I;&5N86UE
M"B`@("`@("`@)'1M<&YA;64@/7X@<R]<+EM>+ETJ)"\N9&ER+SL*("`@("`@
M("!M>2`D;F5W1&ER(#T@1FEL93HZ4W!E8RT^8V%T<&%T:"@*("`@("`@("`@
M("`@*$9I;&4Z.E-P96,M/G-P;&ET<&%T:"@D<&%R7W1E;7`I*5LP+BXQ72P@
M)'1M<&YA;64I.PH@("`@("`@(&EF("AR96YA;64@)'!A<E]T96UP+"`D;F5W
M1&ER*2!["B`@("`@("`@("`@(&]U=',H(E)E;F%M960@)'!A<E]T96UP('1O
M("1N97=$:7(B*3L*("`@("`@("`@("`@)'!A<E]T96UP(#T@)&YE=T1I<CL*
M("`@("`@("!]"@H@("`@("`@(&EF("@D7D\@/7X@;2]W:6XS,B]I*2!["B`@
M("`@("`@("`@('!R:6YT("1T;7`@(@HZ;&]O<`IR;61I<B`O<2`O<R!<(B1P
M87)?=&5M<%PB"FEF(&5X:7-T(%PB)'!A<E]T96UP7"(@9V]T;R!L;V]P"G)M
M9&ER(%PB)'1O<&1I<EPB"G)M(%PB(B`N("1T;7`M/F9I;&5N86UE("X@(EPB
M"B(["B`@("`@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@("`@(&UY("1P
M<F]C.PH@("`@("`@("`@("!7:6XS,CHZ4')O8V5S<SHZ0W)E871E*`H@("`@
M("`@("`@("`@("`@)'!R;V,L("1%3E9[0T]-4U!%0WTL"B`@("`@("`@("`@
M("`@("`B)$5.5GM#3TU34$5#?2`O8R!<(B(@+B`D=&UP+3YF:6QE;F%M92`N
M(")<(B`^;G5L(#(^;G5L("(L"B`@("`@("`@("`@("`@("`Q+"!.3U)-04Q?
M4%))3U))5%E?0TQ!4U,L("(N(@H@("`@("`@("`@("`I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IW:&EL
M92!;("UD("<D<&%R7W1E;7`G(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP
M)PID;VYE"G)M9&ER("<D=&]P9&ER)PIR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M
M93L*("`@("`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@("`@(&-L;W-E("1T;7`["B`@
M("`@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!]"B`@("`@("`@;W5T
M<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`I*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*
M("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6
M>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%2
M1U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?
M05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E
M('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[
M)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R
M;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@
M/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I
M;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@
M("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I
M;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*
M("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L
M("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S
M<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R
M.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@
M("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@
M(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL
M;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B
M)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@
M("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@
M("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE
M*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O
M=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@
M("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S
M92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@
M("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@
M("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D
M97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD[
M"B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@
M9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@
M("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]
M/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@
M("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@
M("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C
M('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@
M("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E
M7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U
M;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K
M97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@
M("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO
M9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^
M>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@
M("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F
M:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@
M("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R
M:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L
M;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D
M9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E
M*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@
M("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D
M;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL
M(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O
M8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@
M("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN
M9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ
M1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%
M7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@
M("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@
M9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I
M*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@
M4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@
M("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@
M("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC
M('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"B1Q
M=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*"B,@1&]N)W0@<W=A
M;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO
M=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T
M7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@
M("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@
M("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D[
M"@H@("`@;7D@0&%D9%]T;U]I;F,["B`@("!W:&EL92`H0$%21U8I('L*("`@
M("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PH*("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@
M('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@
M("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@('T*("`@("`@("!E
M;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("1O=70@/2`D,CL*("`@
M("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@
M("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H
M)#$@97$@)T(G*2!["B`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@
M("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@
M("`D<75I970@/2`Q.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@
M)TPG*2!["B`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@)&-A8VAE7VYA
M;64@/2`D,CL*("`@("`@("!]"@H@("`@("`@('-H:69T*$!!4D=6*3L*"B`@
M("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@
M("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@("!I;FET
M7VEN8R@I.PH@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@
M("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@
M("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H@("`@?0H*("`@('5N<VAI
M9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD
M96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD
M;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H
M:79E.CI::7`["B`@("!]"@H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD[
M"B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@
M("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD
M("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@
M("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]
M"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@
M("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M
M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P
M96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@
M7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2
M+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D
M92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@
M=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A
M=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D
M9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P
M;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]
M"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@
M("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D
M;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@
M("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@
M("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E
M<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U
M;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@
M<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@(')E
M<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@
M("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!]
M(&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@
M>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@
M("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@
M("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@:68@*"1#;VYF:6=[7V1E;&EM
M?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@0&EN8R!]"@H@("`@("`@(&UY
M("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`D9FEL97-[)#%]*RL@
M9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S
M("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG
M>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E
M86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M
M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@
M)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#
M8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E
M<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@
M(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@
M("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@
M("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@
M("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@
M("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE
M(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@
M("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@
M/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@
M("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@
M=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C
M;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R
M>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")8
M4TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S
M*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R
M:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H
M<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@
M("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT
M*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E
M(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@
M("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@
M("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T
M.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I
M;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V
M97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[
M"B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE
M*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O
M=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@
M8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@
M("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F
M:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C
M:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]
M"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM[
M"GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?
M9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@
M86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E
M(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@
M("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&
M:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R
M(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[
M4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_
M<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R
M<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@
M("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R
M86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@
M("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I
M;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&]U=',H<7$H
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]
M?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G
M92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@
M("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*
M("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@
M(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H
M.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I
M97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L
M;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7
M:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D
M97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*
M("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R
M97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@
M("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@
M(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@
M("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@
M(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB
M.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*
M("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T
M.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!E=F%L
M('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,CHZ4')O8V5S<R!].PH@("`@979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*?0H*(R!4:&4@0R!V97)S:6]N
M(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*<W5B
M(%]S971?<&%R7W1E;7`@>PH@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@
M/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R
M;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W
M;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]
M("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E
M;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@
M)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@
M("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@
M("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F
M(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B
M=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@
M("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@
M:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#
M3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U
M.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*
M("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P
M87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@
M("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L
M<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR
M("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N
M86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D
M9F@L("1F:6QE;F%M92D["GT*"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF
M("@D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@
M("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A
M;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@
M("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US
M("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N
M9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I
M9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*
M"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@
M("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@
M("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@
M("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@
M>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W
M;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H
M;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET
M7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%2
M1U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@
M("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*
M"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@
M("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E
M>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V
M86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB
M*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@
M<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P
M<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@
M<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q
M=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@
M<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP
M="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@
M(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@
M('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN
M92`Q,#$W"@I?7T5.1%]?"@```!<0```71`@!``@````(```<+```'+P(!``(
M````"```',```!S0"```"`````@``!S4```=#`@```@````(```=$```'2`(
M```(````"```'20``!V4"`$`&`````@``!V8```>I`@!`!@```((```>J```
M'_`(`0`8````$```'_0``"`H"`$`&`````@``"`L```C^`@"`!@````0```C
M_```)(@(`0`8````"```)(P``"7`"`$`&```!!```"7$```EZ`@!`!@````(
M```E[```*.`(`0`8```"$```*.0``"ED"`$`$`````@``"EH```K9`@!`!@`
M```(```K:```+5P(`0`8````$```+6```"WX"`$`&`````@``"W\``!/$`@!
M`!`````X``!/%```3Y0(`0`0````"```3Y@``%%4"`$`&`````@``%%8``!3
MH`@!`!@````(``!3I```54P(`0`8````$```55```%6H"`$`&````!```%6L
M``!7,`@"`!@````0``!7-```7]`(`@`8```0,```7]0``&%H"`(`&````!@`
M`&%L``!B$`@!`!@````(``!B%```94@(`@`8````$```94P``&78"`$`&```
M``@``&7<``!LT`@!`!@````0``!LU```;70(`0`8````"```;7@``')D"`$`
M&````!```')H``!RC`@```@```````!RD```<I`(````````````<I0``',X
M"`<`"````!```',\``!S6`@```@```````!S7```<W@(```(````````<WP`
M`'.02````````````'.4``!TI`@"``@````(``!TJ```=1P(`P`(````$```
M=2```'4P"```"`````@``'4T``!U-`@```````````!U.```=5P(`0`(````
M"`$;`SL````0`````?__G4P````H````$``````!>E(``00"`1L,'@`````8
M````&/__G1P```$4`$@3<$2#`80`$0)[`````/____\`````_____P``````
M`````````0````$````!```"R`````$```+3`````0```MT````!```#&P``
M``$```0N````#``!%Q`````-``%U.`````0``0%$````!0`!"^`````&``$$
MH`````H```7:````"P```!`````#``'GE````!4``````````@```]@````4
M````!P```!<``1,H````!P`!$P0````(````)`````D````,;____@`!$J1O
M____`````F____```1&Z````````````````````````````````````````
M`````````````````````````````````````76T``%UN/____\``7C(``!:
MMP`!8A0``>>4``%LU``!YY0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````Z`
M$);JP,``#H@0E>J?']W6@!P>`,#_[MZMON\``>:D```````!^L@``?K,````
M```!YY@``>:0``'FD`!'0T,Z("A'3E4I(#0N,BXS("A$96)I86X@-"XR+C,M
M,BD``$=#0SH@*$=.52D@-"XR+C,@*$1E8FEA;B`T+C(N,RTR*0``1T-#.B`H
M1&5B:6%N(#0N,RXP+3,I(#0N,RXQ(#(P,#@P-#`Q("AP<F5R96QE87-E*0``
M1T-#.B`H1&5B:6%N(#0N,RXP+3,I(#0N,RXQ(#(P,#@P-#`Q("AP<F5R96QE
M87-E*0``1T-#.B`H1&5B:6%N(#0N,RXP+3,I(#0N,RXQ(#(P,#@P-#`Q("AP
M<F5R96QE87-E*0``1T-#.B`H1TY5*2`T+C(N,R`H1&5B:6%N(#0N,BXS+3(I
M``!'0T,Z("A'3E4I(#0N,BXS("A$96)I86X@-"XR+C,M,BD``$=#0SH@*$=.
M52D@-"XR+C,@*$1E8FEA;B`T+C(N,RTR*0``1T-#.B`H1TY5*2`T+C(N,R`H
M1&5B:6%N(#0N,BXS+3(I``!'0T,Z("A$96)I86X@-"XS+C`M,RD@-"XS+C$@
M,C`P.#`T,#$@*'!R97)E;&5A<V4I``!'0T,Z("A$96)I86X@-"XS+C`M,RD@
M-"XS+C$@,C`P.#`T,#$@*'!R97)E;&5A<V4I``!'0T,Z("A'3E4I(#0N,BXS
M("A$96)I86X@-"XR+C,M,BD`````!@`````````!,#$N,#$````````&````
M``````$P,2XP,0````````8``````````3`Q+C`Q````````!@`````````!
M,#$N,#$````````&``````````$P,2XP,0````````8``````````3`Q+C`Q
M`````"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+E!!
M4DE30RYU;G=I;F0`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD
M=&]R<P`N:F-R`"YD>6YA;6EC`"YD871A`"YG;W0`+F)S<P`N8V]M;65N=``N
M;F]T90``````````````````````````````````````````````````````
M``````L````!`````@`!`10```$4````#0```````````````0`````````3
M````!P````(``0$D```!)````"````````````````0`````````(0````4`
M```"``$!1````40```-<````!``````````$````!````"<````+`````@`!
M!*````2@```'0`````4````!````!````!`````O`````P````(``0O@```+
MX```!=H```````````````$`````````-V____\````"``$1N@``$;H```#H
M````!``````````"`````@```$1O___^`````@`!$J0``!*D````8`````4`
M```"````!`````````!3````!`````(``1,$```3!````"0````$````````
M``0````,````70````0````"``$3*```$R@```/8````!````!8````$````
M#````&<````!````!@`!%P```!<`````2```````````````!`````````!M
M`````0````8``1=(```72```7?````````````````0`````````<P````$`
M```&``%U.```=3@````H```````````````$`````````'D````!`````@`!
M=6```'5@``!>*```````````````"`````````"!`````0````(``=.(``#3
MB````L``````````"P````0````$````D`````$````"``'62```UD@````4
M```````````````$`````````)X````!`````@`!UEP``-9<````-```````
M````````!`````````"H`````0````,``>:0``#6D`````@`````````````
M``0`````````KP````$````#``'FF```UI@````(```````````````$````
M`````+8````!`````P`!YJ```-:@````!```````````````!`````````"[
M````!@````,``>:D``#6I````/`````%``````````0````(````Q`````$`
M```#``'GE```UY0````<```````````````$`````````&(````!````!P`!
MY[```->P```"O```````````````!`````@```#*`````0````,``>IL``#:
M;````"````````````````0````$````SP````@````#``'JD```VHP``!!(
M```````````````(`````````-0````!`````````````-J,```!]```````
M`````````0````````#=````!P````````````#<@````'@`````````````
M``$``````````0````,`````````````W/@```#C```````````````!````
!````
